@@ -1,15 +1,37 @@
 """Test utilities and fixtures."""
+
 import datetime as dt
+import functools
+import typing
 import uuid
+from enum import Enum, IntEnum
+from zoneinfo import ZoneInfo
 
 import simplejson
 
-import pytz
-
-from marshmallow import Schema, fields, post_load, validate, missing
+from marshmallow import Schema, fields, missing, post_load, validate
 from marshmallow.exceptions import ValidationError
 
-central = pytz.timezone("US/Central")
+central = ZoneInfo("America/Chicago")
+
+
+class GenderEnum(IntEnum):
+    male = 1
+    female = 2
+    non_binary = 3
+
+
+class HairColorEnum(Enum):
+    black = "black hair"
+    brown = "brown hair"
+    blond = "blond hair"
+    red = "red hair"
+
+
+class DateEnum(Enum):
+    date_1 = dt.date(2004, 2, 29)
+    date_2 = dt.date(2008, 2, 29)
+    date_3 = dt.date(2012, 2, 29)
 
 
 ALL_FIELDS = [
@@ -17,7 +39,6 @@ ALL_FIELDS = [
     fields.Integer,
     fields.Boolean,
     fields.Float,
-    fields.Number,
     fields.DateTime,
     fields.Time,
     fields.Date,
@@ -33,24 +54,41 @@ ALL_FIELDS = [
     fields.IPInterface,
     fields.IPv4Interface,
     fields.IPv6Interface,
+    functools.partial(fields.Enum, GenderEnum),
+    functools.partial(fields.Enum, HairColorEnum, by_value=fields.String),
+    functools.partial(fields.Enum, GenderEnum, by_value=fields.Integer),
 ]
 
+
 ##### Custom asserts #####
 
 
-def assert_date_equal(d1, d2):
+def assert_date_equal(d1: dt.date, d2: dt.date) -> None:
     assert d1.year == d2.year
     assert d1.month == d2.month
     assert d1.day == d2.day
 
 
-def assert_time_equal(t1, t2):
+def assert_time_equal(t1: dt.time, t2: dt.time) -> None:
     assert t1.hour == t2.hour
     assert t1.minute == t2.minute
     assert t1.second == t2.second
     assert t1.microsecond == t2.microsecond
 
 
+##### Validation #####
+
+
+def predicate(
+    func: typing.Callable[[typing.Any], bool],
+) -> typing.Callable[[typing.Any], None]:
+    def validate(value: typing.Any) -> None:
+        if func(value) is False:
+            raise ValidationError("Invalid value.")
+
+    return validate
+
+
 ##### Models #####
 
 
@@ -60,6 +98,7 @@ class User:
     def __init__(
         self,
         name,
+        *,
         age=0,
         id_=None,
         homepage=None,
@@ -69,7 +108,8 @@ class User:
         birthdate=None,
         birthtime=None,
         balance=100,
-        sex="male",
+        sex=GenderEnum.male,
+        hair_color=HairColorEnum.black,
         employer=None,
         various_data=None,
     ):
@@ -78,16 +118,14 @@ class User:
         # A naive datetime
         self.created = dt.datetime(2013, 11, 10, 14, 20, 58)
         # A TZ-aware datetime
-        self.updated = central.localize(
-            dt.datetime(2013, 11, 10, 14, 20, 58), is_dst=False
-        )
+        self.updated = dt.datetime(2013, 11, 10, 14, 20, 58, tzinfo=central)
         self.id = id_
         self.homepage = homepage
         self.email = email
         self.balance = balance
-        self.registered = True
-        self.hair_colors = ["black", "brown", "blond", "redhead"]
-        self.sex_choices = ("male", "female")
+        self.registered = registered
+        self.hair_colors = list(HairColorEnum.__members__)
+        self.sex_choices = list(GenderEnum.__members__)
         self.finger_count = 10
         self.uid = uuid.uuid1()
         self.time_registered = time_registered or dt.time(1, 23, 45, 6789)
@@ -95,11 +133,12 @@ class User:
         self.birthtime = birthtime or dt.time(0, 1, 2, 3333)
         self.activation_date = dt.date(2013, 12, 11)
         self.sex = sex
+        self.hair_color = hair_color
         self.employer = employer
         self.relatives = []
         self.various_data = various_data or {
             "pets": ["cat", "dog"],
-            "address": "1600 Pennsylvania Ave\n" "Washington, DC 20006",
+            "address": "1600 Pennsylvania Ave\nWashington, DC 20006",
         }
 
     @property
@@ -107,7 +146,7 @@ class User:
         return dt.datetime(2013, 11, 24) - self.created
 
     def __repr__(self):
-        return "<User {}>".format(self.name)
+        return f"<User {self.name}>"
 
 
 class Blog:
@@ -130,32 +169,32 @@ class DummyModel:
         return self.foo == other.foo
 
     def __str__(self):
-        return "bar {}".format(self.foo)
+        return f"bar {self.foo}"
 
 
 ###### Schemas #####
 
 
-class Uppercased(fields.Field):
+class Uppercased(fields.String):
     """Custom field formatting example."""
 
-    def _serialize(self, value, attr, obj):
+    def _serialize(self, value, attr, obj, **kwargs):
         if value:
             return value.upper()
+        return None
 
 
 def get_lowername(obj):
     if obj is None:
         return missing
     if isinstance(obj, dict):
-        return obj.get("name").lower()
-    else:
-        return obj.name.lower()
+        return obj.get("name", "").lower()
+    return obj.name.lower()
 
 
 class UserSchema(Schema):
     name = fields.String()
-    age = fields.Float()
+    age: fields.Field = fields.Float()
     created = fields.DateTime()
     created_formatted = fields.DateTime(
         format="%Y-%m-%d", attribute="created", dump_only=True
@@ -163,12 +202,12 @@ class UserSchema(Schema):
     created_iso = fields.DateTime(format="iso", attribute="created", dump_only=True)
     updated = fields.DateTime()
     species = fields.String(attribute="SPECIES")
-    id = fields.String(default="no-id")
+    id = fields.String(dump_default="no-id")
     uppername = Uppercased(attribute="name", dump_only=True)
     homepage = fields.Url()
     email = fields.Email()
     balance = fields.Decimal()
-    is_old = fields.Method("get_is_old")
+    is_old: fields.Field = fields.Method("get_is_old")
     lowername = fields.Function(get_lowername)
     registered = fields.Boolean()
     hair_colors = fields.List(fields.Raw)
@@ -180,7 +219,7 @@ class UserSchema(Schema):
     birthtime = fields.Time()
     activation_date = fields.Date()
     since_created = fields.TimeDelta()
-    sex = fields.Str(validate=validate.OneOf(["male", "female"]))
+    sex = fields.Str(validate=validate.OneOf(list(GenderEnum.__members__)))
     various_data = fields.Dict()
 
     class Meta:
@@ -190,7 +229,7 @@ class UserSchema(Schema):
         if obj is None:
             return missing
         if isinstance(obj, dict):
-            age = obj.get("age")
+            age = obj.get("age", 0)
         else:
             age = obj.age
         try:
@@ -203,71 +242,13 @@ class UserSchema(Schema):
         return User(**data)
 
 
-class UserMetaSchema(Schema):
-    """The equivalent of the UserSchema, using the ``fields`` option."""
-
-    uppername = Uppercased(attribute="name", dump_only=True)
-    balance = fields.Decimal()
-    is_old = fields.Method("get_is_old")
-    lowername = fields.Function(get_lowername)
-    species = fields.String(attribute="SPECIES")
-    homepage = fields.Url()
-    email = fields.Email()
-    various_data = fields.Dict()
-
-    def get_is_old(self, obj):
-        if obj is None:
-            return missing
-        if isinstance(obj, dict):
-            age = obj.get("age")
-        else:
-            age = obj.age
-        try:
-            return age > 80
-        except TypeError as te:
-            raise ValidationError(str(te)) from te
-
-    class Meta:
-        fields = (
-            "name",
-            "age",
-            "created",
-            "updated",
-            "id",
-            "homepage",
-            "uppername",
-            "email",
-            "balance",
-            "is_old",
-            "lowername",
-            "species",
-            "registered",
-            "hair_colors",
-            "sex_choices",
-            "finger_count",
-            "uid",
-            "time_registered",
-            "birthdate",
-            "birthtime",
-            "since_created",
-            "various_data",
-        )
-
-
 class UserExcludeSchema(UserSchema):
     class Meta:
         exclude = ("created", "updated")
 
 
-class UserAdditionalSchema(Schema):
-    lowername = fields.Function(lambda obj: obj.name.lower())
-
-    class Meta:
-        additional = ("name", "age", "created", "email")
-
-
 class UserIntSchema(UserSchema):
-    age = fields.Integer()  # type: ignore
+    age = fields.Integer()
 
 
 class UserFloatStringSchema(UserSchema):
@@ -275,7 +256,7 @@ class UserFloatStringSchema(UserSchema):
 
 
 class ExtendedUserSchema(UserSchema):
-    is_old = fields.Boolean()  # type: ignore
+    is_old = fields.Boolean()
 
 
 class UserRelativeUrlSchema(UserSchema):
@@ -290,21 +271,6 @@ class BlogSchema(Schema):
     id = fields.String()
 
 
-class BlogUserMetaSchema(Schema):
-    user = fields.Nested(UserMetaSchema())
-    collaborators = fields.List(fields.Nested(UserMetaSchema()))
-
-
-class BlogSchemaMeta(Schema):
-    """Same as BlogSerializer but using ``fields`` options."""
-
-    user = fields.Nested(UserSchema)
-    collaborators = fields.List(fields.Nested(UserSchema()))
-
-    class Meta:
-        fields = ("title", "user", "collaborators", "categories", "id")
-
-
 class BlogOnlySchema(Schema):
     title = fields.String()
     user = fields.Nested(UserSchema)
@@ -319,7 +285,7 @@ class BlogSchemaOnlyExclude(BlogSchema):
     user = fields.Nested(UserSchema, only=("name",), exclude=("name", "species"))
 
 
-class mockjson:  # noqa
+class mockjson:  # noqa: N801
     @staticmethod
     def dumps(val):
         return b"{'foo': 42}"
