@@ -1,17 +1,24 @@
 """Tests for field serialization."""
-from collections import namedtuple, OrderedDict
+
 import datetime as dt
-import itertools
 import decimal
-import uuid
 import ipaddress
+import itertools
 import math
+import uuid
+from collections import OrderedDict
+from typing import NamedTuple
 
 import pytest
 
-from marshmallow import Schema, fields, missing as missing_
+from marshmallow import Schema, fields
+from marshmallow import missing as missing_
+from tests.base import ALL_FIELDS, DateEnum, GenderEnum, HairColorEnum, User, central
 
-from tests.base import User, ALL_FIELDS, central, GenderEnum, HairColorEnum, DateEnum
+
+class Point(NamedTuple):
+    x: int
+    y: int
 
 
 class DateTimeList:
@@ -34,27 +41,9 @@ class TestFieldSerialization:
     def user(self):
         return User("Foo", email="foo@bar.com", age=42)
 
-    @pytest.mark.parametrize(
-        ("value", "expected"), [(42, float(42)), (0, float(0)), (None, None)]
-    )
-    def test_number(self, value, expected, user):
-        field = fields.Number()
-        user.age = value
-        assert field.serialize("age", user) == expected
-
-    def test_number_as_string(self, user):
-        user.age = 42
-        field = fields.Number(as_string=True)
-        assert field.serialize("age", user) == str(float(user.age))
-
-    def test_number_as_string_passed_none(self, user):
-        user.age = None
-        field = fields.Number(as_string=True, allow_none=True)
-        assert field.serialize("age", user) is None
-
     def test_function_field_passed_func(self, user):
         field = fields.Function(lambda obj: obj.name.upper())
-        assert "FOO" == field.serialize("key", user)
+        assert field.serialize("key", user) == "FOO"
 
     def test_function_field_passed_serialize_only_is_dump_only(self, user):
         field = fields.Function(serialize=lambda obj: obj.name.upper())
@@ -68,12 +57,12 @@ class TestFieldSerialization:
 
     def test_function_field_passed_serialize(self, user):
         field = fields.Function(serialize=lambda obj: obj.name.upper())
-        assert "FOO" == field.serialize("key", user)
+        assert field.serialize("key", user) == "FOO"
 
     # https://github.com/marshmallow-code/marshmallow/issues/395
     def test_function_field_does_not_swallow_attribute_error(self, user):
         def raise_error(obj):
-            raise AttributeError()
+            raise AttributeError
 
         field = fields.Function(serialize=raise_error)
         with pytest.raises(AttributeError):
@@ -102,19 +91,9 @@ class TestFieldSerialization:
         field = fields.Function(deserialize=lambda obj: None)
         assert field.load_only
 
-    def test_function_field_passed_serialize_with_context(self, user, monkeypatch):
-        class Parent(Schema):
-            pass
-
-        field = fields.Function(
-            serialize=lambda obj, context: obj.name.upper() + context["key"]
-        )
-        field.parent = Parent(context={"key": "BAR"})
-        assert "FOOBAR" == field.serialize("key", user)
-
     def test_function_field_passed_uncallable_object(self):
         with pytest.raises(TypeError):
-            fields.Function("uncallable")
+            fields.Function("uncallable")  # type: ignore[arg-type]
 
     def test_integer_field(self, user):
         field = fields.Integer()
@@ -259,8 +238,8 @@ class TestFieldSerialization:
         field = fields.Enum(HairColorEnum, by_value=True)
         assert field.serialize("hair_color", user) == "black hair"
         user.sex = GenderEnum.male
-        field = fields.Enum(GenderEnum, by_value=True)
-        assert field.serialize("sex", user) == 1
+        field2 = fields.Enum(GenderEnum, by_value=True)
+        assert field2.serialize("sex", user) == 1
         user.some_date = DateEnum.date_1
 
     def test_enum_field_by_value_field_serialization(self, user):
@@ -268,11 +247,11 @@ class TestFieldSerialization:
         field = fields.Enum(HairColorEnum, by_value=fields.String)
         assert field.serialize("hair_color", user) == "black hair"
         user.sex = GenderEnum.male
-        field = fields.Enum(GenderEnum, by_value=fields.Integer)
-        assert field.serialize("sex", user) == 1
+        field2 = fields.Enum(GenderEnum, by_value=fields.Integer)
+        assert field2.serialize("sex", user) == 1
         user.some_date = DateEnum.date_1
-        field = fields.Enum(DateEnum, by_value=fields.Date(format="%d/%m/%Y"))
-        assert field.serialize("some_date", user) == "29/02/2004"
+        field3 = fields.Enum(DateEnum, by_value=fields.Date(format="%d/%m/%Y"))
+        assert field3.serialize("some_date", user) == "29/02/2004"
 
     def test_decimal_field(self, user):
         user.m1 = 12
@@ -353,31 +332,38 @@ class TestFieldSerialization:
 
         m1s = field.serialize("m1", user)
         assert isinstance(m1s, decimal.Decimal)
-        assert m1s.is_qnan() and not m1s.is_signed()
+        assert m1s.is_qnan()
+        assert not m1s.is_signed()
 
         m2s = field.serialize("m2", user)
         assert isinstance(m2s, decimal.Decimal)
-        assert m2s.is_qnan() and not m2s.is_signed()
+        assert m2s.is_qnan()
+        assert not m2s.is_signed()
 
         m3s = field.serialize("m3", user)
         assert isinstance(m3s, decimal.Decimal)
-        assert m3s.is_qnan() and not m3s.is_signed()
+        assert m3s.is_qnan()
+        assert not m3s.is_signed()
 
         m4s = field.serialize("m4", user)
         assert isinstance(m4s, decimal.Decimal)
-        assert m4s.is_qnan() and not m4s.is_signed()
+        assert m4s.is_qnan()
+        assert not m4s.is_signed()
 
         m5s = field.serialize("m5", user)
         assert isinstance(m5s, decimal.Decimal)
-        assert m5s.is_infinite() and m5s.is_signed()
+        assert m5s.is_infinite()
+        assert m5s.is_signed()
 
         m6s = field.serialize("m6", user)
         assert isinstance(m6s, decimal.Decimal)
-        assert m6s.is_infinite() and not m6s.is_signed()
+        assert m6s.is_infinite()
+        assert not m6s.is_signed()
 
         m7s = field.serialize("m7", user)
         assert isinstance(m7s, decimal.Decimal)
-        assert m7s.is_zero() and m7s.is_signed()
+        assert m7s.is_zero()
+        assert m7s.is_signed()
 
         field = fields.Decimal(as_string=True, allow_nan=True)
 
@@ -400,7 +386,8 @@ class TestFieldSerialization:
 
         m7s = field.serialize("m7", user)
         assert isinstance(m7s, decimal.Decimal)
-        assert m7s.is_zero() and m7s.is_signed()
+        assert m7s.is_zero()
+        assert m7s.is_signed()
 
     def test_decimal_field_fixed_point_representation(self, user):
         """
@@ -424,17 +411,6 @@ class TestFieldSerialization:
         assert isinstance(s, str)
         assert s == "0.00"
 
-    def test_boolean_field_serialization(self, user):
-        field = fields.Boolean()
-
-        user.truthy = "non-falsy-ish"
-        user.falsy = "false"
-        user.none = None
-
-        assert field.serialize("truthy", user) is True
-        assert field.serialize("falsy", user) is False
-        assert field.serialize("none", user) is None
-
     def test_email_field_serialize_none(self, user):
         user.email = None
         field = fields.Email()
@@ -512,7 +488,7 @@ class TestFieldSerialization:
             mfield = fields.Method("raise_error")
 
             def raise_error(self, obj):
-                raise AttributeError()
+                raise AttributeError
 
         with pytest.raises(AttributeError):
             MySchema().dump({})
@@ -521,7 +497,7 @@ class TestFieldSerialization:
         m = fields.Method()
         m.parent = Schema()
 
-        assert m.serialize("", "", "") is missing_
+        assert m.serialize("", "", None) is missing_
 
     def test_serialize_with_data_key_param(self):
         class DumpToSchema(Schema):
@@ -534,7 +510,7 @@ class TestFieldSerialization:
 
     def test_serialize_with_data_key_as_empty_string(self):
         class MySchema(Schema):
-            name = fields.Field(data_key="")
+            name = fields.Raw(data_key="")
 
         schema = MySchema()
         assert schema.dump({"name": "Grace"}) == {"": "Grace"}
@@ -564,7 +540,7 @@ class TestFieldSerialization:
                 "Sun, 10 Nov 2013 01:23:45 +0000",
             ),
             (
-                central.localize(dt.datetime(2013, 11, 10, 1, 23, 45), is_dst=False),
+                dt.datetime(2013, 11, 10, 1, 23, 45, tzinfo=central),
                 "Sun, 10 Nov 2013 01:23:45 -0600",
             ),
         ],
@@ -585,7 +561,7 @@ class TestFieldSerialization:
             ),
             (
                 "timestamp",
-                central.localize(dt.datetime(2013, 11, 10, 0, 23, 45), is_dst=False),
+                dt.datetime(2013, 11, 10, 0, 23, 45, tzinfo=central),
                 1384064625,
             ),
             ("timestamp_ms", dt.datetime(2013, 11, 10, 0, 23, 45), 1384043025000),
@@ -596,7 +572,7 @@ class TestFieldSerialization:
             ),
             (
                 "timestamp_ms",
-                central.localize(dt.datetime(2013, 11, 10, 0, 23, 45), is_dst=False),
+                dt.datetime(2013, 11, 10, 0, 23, 45, tzinfo=central),
                 1384064625000,
             ),
         ],
@@ -619,7 +595,7 @@ class TestFieldSerialization:
                 "2013-11-10T01:23:45+00:00",
             ),
             (
-                central.localize(dt.datetime(2013, 11, 10, 1, 23, 45), is_dst=False),
+                dt.datetime(2013, 11, 10, 1, 23, 45, tzinfo=central),
                 "2013-11-10T01:23:45-06:00",
             ),
         ],
@@ -633,9 +609,9 @@ class TestFieldSerialization:
         assert field.serialize("d", {"d": value}) == expected
 
     def test_datetime_field_format(self, user):
-        format = "%Y-%m-%d"
-        field = fields.DateTime(format=format)
-        assert field.serialize("created", user) == user.created.strftime(format)
+        datetimeformat = "%Y-%m-%d"
+        field = fields.DateTime(format=datetimeformat)
+        assert field.serialize("created", user) == user.created.strftime(datetimeformat)
 
     def test_string_field(self):
         field = fields.String()
@@ -703,25 +679,25 @@ class TestFieldSerialization:
         )
 
         field = fields.TimeDelta(fields.TimeDelta.DAYS)
-        assert field.serialize("d1", user) == 1
+        assert field.serialize("d1", user) == 1.0000115740856481
         field = fields.TimeDelta(fields.TimeDelta.SECONDS)
-        assert field.serialize("d1", user) == 86401
+        assert field.serialize("d1", user) == 86401.000001
         field = fields.TimeDelta(fields.TimeDelta.MICROSECONDS)
         assert field.serialize("d1", user) == 86401000001
         field = fields.TimeDelta(fields.TimeDelta.HOURS)
-        assert field.serialize("d1", user) == 24
+        assert field.serialize("d1", user) == 24.000277778055555
 
         field = fields.TimeDelta(fields.TimeDelta.DAYS)
-        assert field.serialize("d2", user) == 1
+        assert field.serialize("d2", user) == 1.0000115740856481
         field = fields.TimeDelta(fields.TimeDelta.SECONDS)
-        assert field.serialize("d2", user) == 86401
+        assert field.serialize("d2", user) == 86401.000001
         field = fields.TimeDelta(fields.TimeDelta.MICROSECONDS)
         assert field.serialize("d2", user) == 86401000001
 
         field = fields.TimeDelta(fields.TimeDelta.DAYS)
-        assert field.serialize("d3", user) == 1
+        assert field.serialize("d3", user) == 1.0000115740856481
         field = fields.TimeDelta(fields.TimeDelta.SECONDS)
-        assert field.serialize("d3", user) == 86401
+        assert field.serialize("d3", user) == 86401.000001
         field = fields.TimeDelta(fields.TimeDelta.MICROSECONDS)
         assert field.serialize("d3", user) == 86401000001
 
@@ -740,38 +716,30 @@ class TestFieldSerialization:
         assert field.serialize("d5", user) == -86400000000
 
         field = fields.TimeDelta(fields.TimeDelta.WEEKS)
-        assert field.serialize("d6", user) == 1
+        assert field.serialize("d6", user) == 1.1489103852529763
         field = fields.TimeDelta(fields.TimeDelta.DAYS)
-        assert field.serialize("d6", user) == 7 + 1
+        assert field.serialize("d6", user) == 8.042372696770833
         field = fields.TimeDelta(fields.TimeDelta.HOURS)
-        assert field.serialize("d6", user) == 7 * 24 + 24 + 1
+        assert field.serialize("d6", user) == 193.0169447225
         field = fields.TimeDelta(fields.TimeDelta.MINUTES)
-        assert field.serialize("d6", user) == 7 * 24 * 60 + 24 * 60 + 60 + 1
-        d6_seconds = (
-            7 * 24 * 60 * 60
-            + 24 * 60 * 60  # 1 week
-            + 60 * 60  # 1 day
-            + 60  # 1 hour
-            + 1  # 1 minute
-        )
+        assert field.serialize("d6", user) == 11581.01668335
         field = fields.TimeDelta(fields.TimeDelta.SECONDS)
-        assert field.serialize("d6", user) == d6_seconds
+        assert field.serialize("d6", user) == 694861.001001
         field = fields.TimeDelta(fields.TimeDelta.MILLISECONDS)
-        assert field.serialize("d6", user) == d6_seconds * 1000 + 1
+        assert field.serialize("d6", user) == 694861001.001
         field = fields.TimeDelta(fields.TimeDelta.MICROSECONDS)
-        assert field.serialize("d6", user) == d6_seconds * 10**6 + 1000 + 1
+        assert field.serialize("d6", user) == 694861001001
 
         user.d7 = None
         assert field.serialize("d7", user) is None
 
-        # https://github.com/marshmallow-code/marshmallow/issues/1856
         user.d8 = dt.timedelta(milliseconds=345)
         field = fields.TimeDelta(fields.TimeDelta.MILLISECONDS)
         assert field.serialize("d8", user) == 345
 
         user.d9 = dt.timedelta(milliseconds=1999)
         field = fields.TimeDelta(fields.TimeDelta.SECONDS)
-        assert field.serialize("d9", user) == 1
+        assert field.serialize("d9", user) == 1.999
 
         user.d10 = dt.timedelta(
             weeks=1,
@@ -783,50 +751,47 @@ class TestFieldSerialization:
             microseconds=742,
         )
 
-        field = fields.TimeDelta(fields.TimeDelta.MICROSECONDS, float)
+        field = fields.TimeDelta(fields.TimeDelta.MICROSECONDS)
         unit_value = dt.timedelta(microseconds=1).total_seconds()
         assert math.isclose(
             field.serialize("d10", user), user.d10.total_seconds() / unit_value
         )
 
-        field = fields.TimeDelta(fields.TimeDelta.MILLISECONDS, float)
+        field = fields.TimeDelta(fields.TimeDelta.MILLISECONDS)
         unit_value = dt.timedelta(milliseconds=1).total_seconds()
         assert math.isclose(
             field.serialize("d10", user), user.d10.total_seconds() / unit_value
         )
 
-        field = fields.TimeDelta(fields.TimeDelta.SECONDS, float)
+        field = fields.TimeDelta(fields.TimeDelta.SECONDS)
         assert math.isclose(field.serialize("d10", user), user.d10.total_seconds())
 
-        field = fields.TimeDelta(fields.TimeDelta.MINUTES, float)
+        field = fields.TimeDelta(fields.TimeDelta.MINUTES)
         unit_value = dt.timedelta(minutes=1).total_seconds()
         assert math.isclose(
             field.serialize("d10", user), user.d10.total_seconds() / unit_value
         )
 
-        field = fields.TimeDelta(fields.TimeDelta.HOURS, float)
+        field = fields.TimeDelta(fields.TimeDelta.HOURS)
         unit_value = dt.timedelta(hours=1).total_seconds()
         assert math.isclose(
             field.serialize("d10", user), user.d10.total_seconds() / unit_value
         )
 
-        field = fields.TimeDelta(fields.TimeDelta.DAYS, float)
+        field = fields.TimeDelta(fields.TimeDelta.DAYS)
         unit_value = dt.timedelta(days=1).total_seconds()
         assert math.isclose(
             field.serialize("d10", user), user.d10.total_seconds() / unit_value
         )
 
-        field = fields.TimeDelta(fields.TimeDelta.WEEKS, float)
+        field = fields.TimeDelta(fields.TimeDelta.WEEKS)
         unit_value = dt.timedelta(weeks=1).total_seconds()
         assert math.isclose(
             field.serialize("d10", user), user.d10.total_seconds() / unit_value
         )
 
-        with pytest.raises(ValueError):
-            fields.TimeDelta(fields.TimeDelta.SECONDS, str)
-
     def test_datetime_list_field(self):
-        obj = DateTimeList([dt.datetime.utcnow(), dt.datetime.now()])
+        obj = DateTimeList([dt.datetime.now(dt.timezone.utc), dt.datetime.now()])
         field = fields.List(fields.DateTime)
         result = field.serialize("dtimes", obj)
         assert all(type(each) is str for each in result)
@@ -838,7 +803,7 @@ class TestFieldSerialization:
 
     def test_list_field_work_with_generator_single_value(self):
         def custom_generator():
-            yield dt.datetime.utcnow()
+            yield dt.datetime.now(dt.timezone.utc)
 
         obj = DateTimeList(custom_generator())
         field = fields.List(fields.DateTime)
@@ -847,14 +812,14 @@ class TestFieldSerialization:
 
     def test_list_field_work_with_generators_multiple_values(self):
         def custom_generator():
-            yield from [dt.datetime.utcnow(), dt.datetime.now()]
+            yield from [dt.datetime.now(dt.timezone.utc), dt.datetime.now()]
 
         obj = DateTimeList(custom_generator())
         field = fields.List(fields.DateTime)
         result = field.serialize("dtimes", obj)
         assert len(result) == 2
 
-    def test_list_field_work_with_generators_empty_generator_returns_none_for_every_non_returning_yield_statement(  # noqa: B950
+    def test_list_field_work_with_generators_empty_generator_returns_none_for_every_non_returning_yield_statement(
         self,
     ):
         def custom_generator():
@@ -900,16 +865,16 @@ class TestFieldSerialization:
             id = fields.Int()
 
         with pytest.raises(ValueError):
-            fields.List("string")
+            fields.List("string")  # type: ignore[arg-type]
         expected_msg = (
             "The list elements must be a subclass or instance of "
-            "marshmallow.base.FieldABC"
+            "marshmallow.fields.Field"
         )
         with pytest.raises(ValueError, match=expected_msg):
-            fields.List(ASchema)
+            fields.List(ASchema)  # type: ignore[arg-type]
 
     def test_datetime_integer_tuple_field(self):
-        obj = DateTimeIntegerTuple((dt.datetime.utcnow(), 42))
+        obj = DateTimeIntegerTuple((dt.datetime.now(dt.timezone.utc), 42))
         field = fields.Tuple([fields.DateTime, fields.Integer])
         result = field.serialize("dtime_int", obj)
         assert type(result[0]) is str
@@ -925,18 +890,18 @@ class TestFieldSerialization:
             id = fields.Int()
 
         with pytest.raises(ValueError):
-            fields.Tuple(["string"])
+            fields.Tuple(["string"])  # type: ignore[arg-type]
         with pytest.raises(ValueError):
-            fields.Tuple(fields.String)
+            fields.Tuple(fields.String)  # type: ignore[arg-type]
         expected_msg = (
             'Elements of "tuple_fields" must be subclasses or '
-            "instances of marshmallow.base.FieldABC."
+            "instances of marshmallow.fields.Field."
         )
         with pytest.raises(ValueError, match=expected_msg):
-            fields.Tuple([ASchema])
+            fields.Tuple([ASchema])  # type: ignore[arg-type]
 
     def test_serialize_does_not_apply_validators(self, user):
-        field = fields.Field(validate=lambda x: False)
+        field = fields.Raw(validate=lambda x: False)
         # No validation error raised
         assert field.serialize("age", user) == user.age
 
@@ -989,9 +954,7 @@ class TestSchemaSerialization:
 
 
 def test_serializing_named_tuple():
-    Point = namedtuple("Point", ["x", "y"])
-
-    field = fields.Field()
+    field = fields.Raw()
 
     p = Point(x=4, y=2)
 
@@ -999,12 +962,11 @@ def test_serializing_named_tuple():
 
 
 def test_serializing_named_tuple_with_meta():
-    Point = namedtuple("Point", ["x", "y"])
     p = Point(x=4, y=2)
 
     class PointSerializer(Schema):
-        class Meta:
-            fields = ("x", "y")
+        x = fields.Int()
+        y = fields.Int()
 
     serialized = PointSerializer().dump(p)
     assert serialized["x"] == 4
@@ -1013,12 +975,12 @@ def test_serializing_named_tuple_with_meta():
 
 def test_serializing_slice():
     values = [{"value": value} for value in range(5)]
-    slice = itertools.islice(values, None)
+    sliced = itertools.islice(values, None)
 
     class ValueSchema(Schema):
         value = fields.Int()
 
-    serialized = ValueSchema(many=True).dump(slice)
+    serialized = ValueSchema(many=True).dump(sliced)
     assert serialized == values
 
 
